# AWS Nuke Exporter

## Hit the Star! :star:

If you find this repository useful, please consider giving it a star. Your support is greatly appreciated! :pray:

## Description
AWS Nuke Exporter is a Python tool designed to parse and export the output logs of the [aws-nuke](https://github.com/rebuy-de/aws-nuke) command into more structured and readable formats: JSON or CSV. This tool simplifies the process of analyzing and storing the results generated by AWS Nuke, making it easier for users to review and track the resources managed by AWS Nuke.

## Features
- **Multiple Output Formats**: Supports exporting data into JSON or CSV formats.
- **Detailed Parsing**: Extracts detailed information from the AWS Nuke logs, including resource types, IDs, regions, and additional details.
- **Customizable Export Paths**: Allows users to specify custom paths for the exported data.

## Requirements
- Python 3
- AWS CLI (for `aws-nuke` command execution)

## Installation

### From PyPI

You can install `aws-nuke-exporter` directly from PyPI:

```bash
pip install aws-nuke-exporter
```

This command will install the latest version of the `aws-nuke-exporter` package along with all necessary dependencies.

### From Source

Alternatively, you can clone the repository and install it manually:

```bash
git clone https://github.com/oijkn/aws-nuke-exporter.git
cd aws-nuke-exporter
python setup.py install
```

## Usage

After installation, you can use `aws-nuke-exporter` from the command line:

```bash
aws-nuke-exporter <path-to-aws-nuke-output> -f <format> -d <destination-path>
```

Or alternatively, build and use the Docker image. To build the image:
```bash
docker build -t aws-nuke-exporter .
```
To use the docker image run it as follows:

```bash
docker run docker run --rm -v $PWD/:/data <image_name> /data/<aws-nuke-output_file> -d /data/<exported_file>
```

### Arguments

- `path-to-aws-nuke-output`: The file path where AWS Nuke output is stored.
- `-f, --format [json|csv]`: The output format. Choose between JSON and CSV (default: JSON).
- `-d, --destination`: The path where the exported file will be saved (optional).
- `-q, --quiet`: Run in quiet mode, no logs will be printed to stdout (default: False).
- `-v, --version`: Prints the version of the tool.

### Examples

Export AWS Nuke output to JSON:

```bash
aws-nuke-exporter output.log -f json
```

Export AWS Nuke output to CSV with a custom destination:

```bash
aws-nuke-exporter output.log -f csv -d /path/to/export.csv
```

Run the docker image, passing in the current directory and exporting as JSON to a file named 'export.json':
```bash
docker run --rm -v $PWD/:/data nuke-export /data/aws-nuke-output.txt -d /data/export.json
```

## Contributing
Contributions to the AWS Nuke Exporter are welcome. Please ensure that your code adheres to the existing style and that all tests pass.

## License
This project is licensed under the [GNU General Public License (GPL)](LICENSE).

## Contact
For any questions or feedback, please open an issue on GitHub.